@@ -24,6 +24,9 @@ def chunk_list(seq, num):
   avg = len(seq) / float(num)
   out = []
   last = 0.0
+  if len(seq) < num:
+      print "Returning a single chunk!"
+      return [seq]
   while last < len(seq):
     out.append(seq[int(last):int(last + avg)])
     last += avg
@@ -176,16 +179,18 @@ def run_on_cluster(cmd, job_name, cluster_output_dir,
         print "Warning: Unknown queue type: %s" %(queue_type)
         queue_name = queue_type
     
-    if queue_type == None:
-        print "  - queue: unspecified"
+    if queue_type is None:
+        print "  - queue type: unspecified"
     else:
-        print "  - queue: %s, using queue name %s" %(queue_type,
-                                                     queue_name)
-
-    #print "  - cmd: %s" %(cmd)
+        print "  - queue type: %s" %(queue_type)
+    if queue_name is None:
+        print " - queue name unspecified"
+    else:
+        print " - queue name: %s" %(queue_name)
+        
     misc_utils.make_dir(cluster_output_dir)
     if cluster_scripts_dir == None:
-	cluster_scripts_dir = os.path.join(cluster_output_dir,
+        cluster_scripts_dir = os.path.join(cluster_output_dir,
                                            'cluster_scripts')
         misc_utils.make_dir(cluster_scripts_dir)
     scripts_output_dir = os.path.join(cluster_output_dir,
