@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+# -*- mode: python; -*-
 ##
 ## Check if all the necessary modules to run MISO are available
 ##
@@ -10,6 +10,7 @@ import misopy.misc_utils as utils
 
 def check_module_availability(required_modules):
     unavailable_mods = 0
+    print "Checking availability of Python modules for MISO"
     print "Looking for required Python modules.."
     for module_name in required_modules:
 	print "Checking for availability of: %s" %(module_name)
@@ -30,10 +31,10 @@ def check_module_availability(required_modules):
                 print "matplotlib is required for sashimi_plot"
 	    unavailable_mods += 1
     if unavailable_mods != 0:
-	print "Total of %d modules were not available. " \
+        print "Total of %d modules were not available. " \
               "Please install these and try again." %(unavailable_mods)
     else:
-	print "All modules are available!"
+        print "All modules are available!"
     print "Looking for required executables.."
     required_programs = ["samtools", "bedtools"]
     for prog in required_programs:
@@ -53,8 +54,12 @@ def check_module_availability(required_modules):
     return unavailable_mods
 
 
-if __name__ == '__main__':
+def main():
     required_modules = ['numpy', 'scipy', 'json', 'matplotlib',
                         'pysam']
     check_module_availability(required_modules)
     
+
+if __name__ == '__main__':
+    main()
+    
