@@ -18,9 +18,7 @@ import misopy.sam_utils as sam_utils
 import misopy.miso_sampler as miso
 import misopy.Gene as gene_utils
 import misopy.gff_utils as gff_utils
-
-import misopy.index_gff as index_gff
-from index_gff import is_compressed_index
+import misopy.misc_utils as misc_utils
 
 from misopy.parse_csv import *
 from misopy.samples_utils import *
@@ -50,10 +48,7 @@ def compute_gene_psi(gene_ids, gff_index_filename, bam_filename,
     - Optional: Run in paired-end mode. Gives mean and standard deviation
       of fragment length distribution.
     """
-    try:
-        os.makedirs(output_dir)
-    except OSError:
-            pass
+    misc_utils.make_dir(output_dir)
         
     if not os.path.exists(gff_index_filename):
         print "Error: No GFF %s" %(gff_index_filename)
@@ -105,7 +100,7 @@ def compute_gene_psi(gene_ids, gff_index_filename, bam_filename,
     bamfile = sam_utils.load_bam_reads(bam_filename,
                                        template=template)
     # Check if we're in compressed mode
-    compressed_mode = is_compressed_index(gff_index_filename)
+    compressed_mode = misc_utils.is_compressed_index(gff_index_filename)
     
     for gene_id, gene_info in gff_genes.iteritems():
         lookup_id = gene_id
@@ -114,6 +109,13 @@ def compute_gene_psi(gene_ids, gff_index_filename, bam_filename,
             continue
         gene_obj = gene_info['gene_object']
         gene_hierarchy = gene_info['hierarchy']
+
+        # Sanity check: if the isoforms are all shorter than the read,
+        # skip the event
+        if all(map(lambda l: l < read_len, gene_obj.iso_lens)):
+            print "All isoforms of %s shorter than %d, so skipping" \
+                  %(gene_id, read_len)
+            continue
         
         # Find the most inclusive transcription start and end sites
         # for each gene
@@ -243,7 +245,7 @@ def run_compute_genes_from_file(options):
         for line in genes_in:
             gene_id, gff_filename = line.strip().split("\t")
             if not os.path.isfile(gff_filename):
-                print "Error: %s does not exist."
+                print "Error: %s does not exist." %(gff_filename)
                 sys.exit(1)
             compute_gene_psi([gene_id], gff_filename, bam_filename,
                              output_dir, options.read_len, overhang_len,
@@ -358,11 +360,6 @@ def main():
                       nargs=1, default=None,
                       help="Label for MISO summary file. If not given, "
                       "uses basename of MISO output directory.")
-    parser.add_option("--summarize-multi-iso-samples", dest="summarize_samples",
-                      nargs=2, default=None,
-		      help="Compute summary statistics of the given set of "
-                      "samples from multi-isoform runs. Expects a directory with "
-                      "MISO output and a directory to output summary file to.")
     parser.add_option("--use-cluster", action="store_true",
                       dest="use_cluster", default=False)
     parser.add_option("--chunk-jobs", dest="chunk_jobs",
@@ -386,7 +383,7 @@ def main():
                       nargs=1, default=None,
                       help="Use compressed event IDs. Takes as input a "
                       "genes_to_filenames.shelve file produced by the "
-                      "index_gff.py script.")
+                      "index_gff script.")
     ##
     ## Gene utilities
     ##
@@ -422,7 +419,7 @@ def main():
 	output_dirname = os.path.abspath(options.samples_to_compare[2])
 	if not os.path.isdir(output_dirname):
             print "Making comparisons directory: %s" %(output_dirname)
-	    os.makedirs(output_dirname)
+            misc_utils.make_dir(output_dirname)
 	ht.output_samples_comparison(sample1_dirname,
                                      sample2_dirname,
                                      output_dirname,
