@@ -46,7 +46,13 @@ def plot_density_single(settings, sample_label,
     TODO: If comparison files are available, plot Bayes factors too.
     """
     bamfile = pysam.Samfile(bam_filename, 'rb')
-    subset_reads = bamfile.fetch(reference=chrom, start=tx_start,end=tx_end)
+    try:
+        subset_reads = bamfile.fetch(reference=chrom, start=tx_start,end=tx_end)
+    except ValueError as e:
+        print "Error retrieving files from %s: %s" %(chrom, str(e))
+        print "Are you sure %s appears in your BAM file?" %(chrom)
+        print "Aborting plot..."
+        return axvar
     wiggle, jxns = readsToWiggle_pysam(subset_reads, tx_start, tx_end)
     wiggle = 1e3 * wiggle / coverage
                 
@@ -139,10 +145,11 @@ def plot_density_single(settings, sample_label,
                                                        strand),
                fontsize=font_size)
         max_graphcoords = max(graphcoords) - 1
+        coords_fontsize = font_size - (font_size * 0.2)
         xticks(linspace(0, max_graphcoords, nxticks),
                [graphToGene[int(x)] for x in \
                 linspace(0, max_graphcoords, nxticks)],
-               fontsize=font_size)
+               fontsize=coords_fontsize)
     else:
         axvar.spines['bottom'].set_color('none')
         xticks([])
@@ -289,7 +296,7 @@ def plot_density(sashimi_obj, pickle_filename, event, plot_title=None):
 
     # Reset axes based on this.
     # Set fake ymin bound to allow lower junctions to be visible
-    fake_ymin = -0.5 * max_used_yval
+    fake_ymin = -0.6 * max_used_yval
     universal_yticks = linspace(0, max_used_yval,
                                 nyticks + 1)
     # Round up yticks
@@ -353,7 +360,7 @@ def plot_density(sashimi_obj, pickle_filename, event, plot_title=None):
     ax = subplot2grid((nfiles + 3, gene_posterior_ratio), (nfiles + 1, 0),
                       colspan=gene_posterior_ratio - 1, rowspan=2)
     plot_mRNAs(tx_start, mRNAs, strand, graphcoords, reverse_minus)
-    subplots_adjust(hspace=.1, wspace=.7)
+    subplots_adjust(hspace=.10, wspace=.7)
 
 
 def getScaling(tx_start, tx_end, strand, exon_starts, exon_ends,
@@ -395,6 +402,10 @@ def readsToWiggle_pysam(reads, tx_start, tx_end):
     wiggle = zeros((tx_end - tx_start + 1), dtype='f')
     jxns = {}
     for read in reads:
+        # Skip reads with no CIGAR string
+        if read.cigar is None:
+            print "Skipping read with no CIGAR string: %s" %(read.cigar)
+            continue
         cigar_str = sam_utils.sam_cigar_to_str(read.cigar)
 
         if ("N" in cigar_str) and (cigar_str.count("N") > 1):
@@ -605,8 +616,8 @@ def plot_posterior_single(miso_f, axvar, posterior_bins,
     # Use same x-axis for all subplots
     # but only show x-axis labels for the bottom plot
     xlim([0, 1])
-    xticks([0, .2, .4, .6, .8, 1])
-    xticks(fontsize=font_size)
+    psi_axis_fontsize = font_size - (font_size * 0.3)
+    xticks([0, .2, .4, .6, .8, 1], fontsize=psi_axis_fontsize)
     
     if (not bar_posterior) and showYaxis:
         axes_to_show = ['bottom', 'left']
